@@ -567,7 +567,7 @@ worker('refresh-pool-servers', 'ht.Pool.__checkPoolNodes__', timesleep=180, run_
 worker('clear-htpass-files', 'ht.Config.__cleanHtPassFiles__', timesleep=100, run_until_ht_stops=True, log=__amidjango__)
 worker('clear-uploaded-modules-temp', 'ht.Repositories.clearUploadsTemp', timesleep=200, run_until_ht_stops=True, log=__amidjango__)
 worker('clear-output-modules', 'ht.__cleanOutputModules__', timesleep=200, run_until_ht_stops=True, log=__amidjango__)
-worker('elastic-search', 'ht.Logger.saveLogElasticSearch()', timesleep=5, run_until_ht_stops=True, log=False)
+worker('elastic-search', 'ht.Logger.saveLogElasticSearch', timesleep=5, run_until_ht_stops=True, log=False)
 
 __importModules__()
 
