@@ -66,7 +66,7 @@ def saveLog():
 
 def saveLogElasticSearch():
     global __logs__
-    with open('hackingtools.log', 'w') as f:
+    with open('hackingtools.log', 'w+') as f:
         for log in getLogs():
             f.write("{log}\n".format(log=log))
 
